============
Installation
============

At the command line to install the stable version from `pypi <https://pypi.python.org/pypi/fabian>`_::

    $ pip install fabian
    
Or if you're developing locally::

    $ python setup.py develop

Or get install the development version from git::

    $ pip install git+https://github.com/ajenta/fabian.git
